@@ -253,9 +253,8 @@ namespace {
         SharedParametersMap::const_iterator i = mSharedParametersMap.find(name);
         if (i == mSharedParametersMap.end())
         {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS, 
-                "No shared parameter set with name '" + name + "'!", 
-                "GpuProgramManager::getSharedParameters");
+            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
+                        "referenced shared_params '" + name + "' not found");
         }
         return i->second;
     }
@@ -352,7 +351,7 @@ namespace {
         }
         
         StreamSerialiser serialiser(stream);
-        serialiser.writeChunkBegin(CACHE_CHUNK_ID, 2);
+        serialiser.writeChunkBegin(CACHE_CHUNK_ID, 3);
 
         // write the size of the array
         uint32 sizeOfArray = static_cast<uint32>(mMicrocodeCache.size());
@@ -392,9 +391,10 @@ namespace {
             return;
         }
 
-        if(chunk->id != CACHE_CHUNK_ID || chunk->version != 2)
+        if(chunk->id != CACHE_CHUNK_ID || chunk->version != 3)
         {
             LogManager::getSingleton().logWarning("Invalid Microcode Cache");
+            serialiser.readChunkEnd(CACHE_CHUNK_ID);
             return;
         }
         // write the size of the array
