@@ -27,10 +27,8 @@ THE SOFTWARE.
 */
 #include "OgreStableHeaders.h"
 #include "OgreStaticGeometry.h"
-#include "OgreEntity.h"
 #include "OgreEdgeListBuilder.h"
 #include "OgreLodStrategy.h"
-#include "OgreSubEntity.h"
 
 namespace Ogre {
 
